@@ -1,27 +1,14 @@
-/******************************************************************************
- *   Copyright (C) 2010 by Sebastian Doerner <sebastian@sebastian-doerner.de> *
- *                                                                            *
- *   This program is free software; you can redistribute it and/or modify     *
- *   it under the terms of the GNU General Public License as published by     *
- *   the Free Software Foundation; either version 2 of the License, or        *
- *   (at your option) any later version.                                      *
- *                                                                            *
- *   This program is distributed in the hope that it will be useful,          *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *   GNU General Public License for more details.                             *
- *                                                                            *
- *   You should have received a copy of the GNU General Public License        *
- *   along with this program; if not, write to the                            *
- *   Free Software Foundation, Inc.,                                          *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA               *
- ******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Sebastian Doerner <sebastian@sebastian-doerner.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "gitwrapper.h"
 
 #include <QTextCodec>
 
-GitWrapper* GitWrapper::m_instance = 0;
+GitWrapper* GitWrapper::m_instance = nullptr;
 const int GitWrapper::BUFFER_SIZE = 256;
 const int GitWrapper::SMALL_BUFFER_SIZE = 128;
 
@@ -33,7 +20,7 @@ GitWrapper::GitWrapper()
 
 GitWrapper* GitWrapper::instance()
 {
-    if (m_instance == 0) {
+    if (m_instance == nullptr) {
         m_instance = new GitWrapper();
     }
     return m_instance;
@@ -42,14 +29,14 @@ GitWrapper* GitWrapper::instance()
 void GitWrapper::freeInstance()
 {
     delete m_instance;
-    m_instance = 0;
+    m_instance = nullptr;
 }
 
 QString GitWrapper::userName()
 {
-    QString result("");
+    QString result;
     char buffer[SMALL_BUFFER_SIZE];
-    m_process.start("git", {"config", "--get", "user.name"});
+    m_process.start(QStringLiteral("git"), {QStringLiteral("config"), QStringLiteral("--get"), QStringLiteral("user.name")});
     while (m_process.waitForReadyRead()) {
         if (m_process.readLine(buffer, sizeof(buffer)) > 0) {
             result = m_localCodec->toUnicode(buffer).trimmed();
@@ -60,9 +47,9 @@ QString GitWrapper::userName()
 
 QString GitWrapper::userEmail()
 {
-    QString result("");
+    QString result;
     char buffer[SMALL_BUFFER_SIZE];
-    m_process.start("git", {"config", "--get", "user.email"});
+    m_process.start(QStringLiteral("git"), {QStringLiteral("config"), QStringLiteral("--get"), QStringLiteral("user.email")});
     while (m_process.waitForReadyRead()) {
         if (m_process.readLine(buffer, sizeof(buffer)) > 0) {
             result = m_localCodec->toUnicode(buffer).trimmed();
@@ -75,18 +62,18 @@ QString GitWrapper::userEmail()
 QStringList GitWrapper::branches(int* currentBranchIndex)
 {
     QStringList result;
-    if (currentBranchIndex != 0) {
+    if (currentBranchIndex != nullptr) {
         *currentBranchIndex = -1;
     }
-    m_process.start("git", {"branch", "-a"});
+    m_process.start(QStringLiteral("git"), {QStringLiteral("branch"), QStringLiteral("-a")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
         while (m_process.readLine(buffer, sizeof(buffer)) > 0){
             const QString branchName = m_localCodec->toUnicode(buffer).mid(2).trimmed();
             //don't list non-branches and HEAD-branches directly pointing to other branches
-            if (!branchName.contains("->") && !branchName.startsWith('(')) {
+            if (!branchName.contains(QLatin1String("->")) && !branchName.startsWith(QLatin1Char('('))) {
                 result.append(branchName);
-                if (currentBranchIndex !=0 && buffer[0]=='*') {
+                if (currentBranchIndex !=nullptr && buffer[0]=='*') {
                     *currentBranchIndex = result.size() - 1;
                 }
             }
@@ -97,7 +84,7 @@ QStringList GitWrapper::branches(int* currentBranchIndex)
 
 void GitWrapper::tagSet(QSet<QString>& result)
 {
-    m_process.start("git", {"tag"});
+    m_process.start(QStringLiteral("git"), {QStringLiteral("tag")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
         while (m_process.readLine(buffer, sizeof(buffer)) > 0){
@@ -110,7 +97,7 @@ void GitWrapper::tagSet(QSet<QString>& result)
 QStringList GitWrapper::tags()
 {
     QStringList result;
-    m_process.start("git", {"tag"});
+    m_process.start(QStringLiteral("git"), {QStringLiteral("tag")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
         while (m_process.readLine(buffer, sizeof(buffer)) > 0){
@@ -124,13 +111,13 @@ QStringList GitWrapper::tags()
 inline QStringList GitWrapper::remotes(QLatin1String lineEnd)
 {
     QStringList result;
-    m_process.start("git", {"remote", "-v"});
+    m_process.start(QStringLiteral("git"), {QStringLiteral("remote"), QStringLiteral("-v")});
     while (m_process.waitForReadyRead()) {
         char buffer[BUFFER_SIZE];
         while (m_process.readLine(buffer, sizeof(buffer)) > 0){
-            const QString line = QString(buffer).simplified();
+            const QString line = QString::fromLocal8Bit(buffer).simplified();
             if (line.endsWith(lineEnd)) {
-                result.append(line.section(' ', 0, 0));
+                result.append(line.section(QLatin1Char(' '), 0, 0));
             }
         }
     }
@@ -151,12 +138,12 @@ QString GitWrapper::lastCommitMessage()
 {
     QString result;
     char buffer[BUFFER_SIZE];
-    m_process.start("git", {"log", "-1"});
+    m_process.start(QStringLiteral("git"), {QStringLiteral("log"), QStringLiteral("-1")});
     while (m_process.waitForReadyRead()) {
         bool inMessage = false;
         QStringList message;
         while (m_process.readLine(buffer, sizeof(buffer)) > 0) {
-            const QString currentLine(buffer);
+            const QString currentLine = QString::fromLocal8Bit(buffer);
             if (inMessage){
                 message << m_localCodec->toUnicode(buffer).trimmed();
             }
@@ -165,7 +152,7 @@ QString GitWrapper::lastCommitMessage()
                 inMessage = true;
             }
         }
-        result = message.join("\n");
+        result = message.join(QLatin1Char('\n'));
     }
     return result;
 }
